import { ref, onBeforeMount, computed } from "vue";
import { useRoute,useRouter } from "vue-router";
import testModel from "@/model/test";


/**获取题目列表 */
export const useSubjectList = (type: ExerciseType.ListType) => {
	type TestModelListResType = Awaited<ReturnType<typeof testModel.getList | typeof testModel.getFreeList>>;

	const subjectList = ref<TestModelListResType["list"]>([]); //题目列表
	const subjectTotal = ref(0); //题目总数
	const query = useRoute().query; //路由query参数

	const vehicle = useRouter().currentRoute.value.query.vehicle as string; //路由qvehicle参数
	const subject = useRouter().currentRoute.value.query.subject as string; //路由subject参数
	onBeforeMount(async () => {
		let res: TestModelListResType;

		if (type == "normal"||type=="test") {
			res = await testModel.getList({
				...query,
			});
		}
		else if(type=="wrong"){
			let wrongSet:[any] =  JSON.parse(window.localStorage.getItem(vehicle+subject)||"[]")
			res  = {
				total:wrongSet.length,
				list:wrongSet
			} as TestModelListResType
			
			

		} 
		else {
			res = await testModel.getFreeList({
				...query,
			});
		}

		subjectList.value = res.list;
		subjectTotal.value = res.total;
	});

	const currentSubjectIndex = ref(0); //当前题目下标
	//当前题目内容
	const currentSubject = computed(() => {
		return subjectList.value[currentSubjectIndex.value];
	});
	return {
		subjectList,
		subjectTotal,
		currentSubject,
		currentSubjectIndex,
	};
};
